@@ -15,6 +15,8 @@
  * 02110-1301, USA.
  */
 
+#[cfg(feature = "decompression")]
+mod decompression;
 pub mod detect;
 pub mod files;
 pub mod http2;
