@@ -69,12 +69,6 @@ pub struct IKEV2State {
     /// The connection state
     connection_state: IKEV2ConnectionState,
 
-    /// The transforms proposed by the initiator
-    pub client_transforms : Vec<Vec<IkeV2Transform>>,
-
-    /// The transforms selected by the responder
-    pub server_transforms : Vec<Vec<IkeV2Transform>>,
-
     /// The encryption algorithm selected by the responder
     pub alg_enc:  IkeTransformEncType,
     /// The authentication algorithm selected by the responder
@@ -125,8 +119,6 @@ impl IKEV2State {
             tx_id: 0,
             connection_state: IKEV2ConnectionState::Init,
             dh_group: IkeTransformDHType::None,
-            client_transforms: Vec::new(),
-            server_transforms: Vec::new(),
             alg_enc: IkeTransformEncType::ENCR_NULL,
             alg_auth: IkeTransformAuthType::NONE,
             alg_prf: IkeTransformPRFType::PRF_NULL,
@@ -184,8 +176,8 @@ impl IKEV2State {
                                         self.dh_group = kex.dh_group;
                                     }
                                 },
-                                IkeV2PayloadContent::Nonce(ref n) => {
-                                    SCLogDebug!("Nonce: {:?}", n);
+                                IkeV2PayloadContent::Nonce(ref _n) => {
+                                    SCLogDebug!("Nonce: {:?}", _n);
                                 },
                                 IkeV2PayloadContent::Notify(ref n) => {
                                     SCLogDebug!("Notify: {:?}", n);
@@ -213,7 +205,7 @@ impl IKEV2State {
                             }
                         };
                     },
-                    e => { SCLogDebug!("parse_ikev2_payload_with_type: {:?}",e); () },
+                    _e => { SCLogDebug!("parse_ikev2_payload_with_type: {:?}", _e); () },
                 }
                 1
             },
@@ -338,8 +330,8 @@ impl IKEV2State {
                             _ => (),
                         }
                     },
-                    IkeV2Transform::Unknown(tx_type,tx_id) => {
-                        SCLogDebug!("Unknown proposal: type={:?}, id={}", tx_type, tx_id);
+                    IkeV2Transform::Unknown(_tx_type, _tx_id) => {
+                        SCLogDebug!("Unknown proposal: type={:?}, id={}", _tx_type, _tx_id);
                         self.set_event(IKEV2Event::UnknownProposal);
                     },
                     _ => (),
@@ -392,11 +384,6 @@ impl IKEV2State {
                                                IkeV2Transform::ESN(ref e) => self.alg_esn = *e,
                                                _ => (),
                                            });
-                SCLogDebug!("Selected transforms: {:?}", transforms);
-                self.server_transforms.push(transforms);
-            } else {
-                SCLogDebug!("Proposed transforms: {:?}", transforms);
-                self.client_transforms.push(transforms);
             }
         }
     }
