@@ -23,10 +23,12 @@ use crate::applayer::{self, LoggerFlags};
 use crate::applayer::*;
 use crate::core::{self, AppProto, Flow, ALPROTO_FAILED, ALPROTO_UNKNOWN, IPPROTO_TCP};
 use num_traits::FromPrimitive;
+use crate::conf::conf_get;
 use nom;
 use std;
 use std::ffi::{CStr,CString};
 use std::mem::transmute;
+use std::collections::VecDeque;
 
 // Used as a special pseudo packet identifier to denote the first CONNECT
 // packet in a connection. Note that there is no risk of collision with a
@@ -37,6 +39,8 @@ const MQTT_CONNECT_PKT_ID: u32 = std::u32::MAX;
 // this value, it will be truncated. Default: 1MB.
 static mut MAX_MSG_LEN: u32 = 1048576;
 
+static mut MQTT_MAX_TX: usize = 1024;
+
 static mut ALPROTO_MQTT: AppProto = ALPROTO_UNKNOWN;
 
 #[derive(FromPrimitive, Debug)]
@@ -51,6 +55,7 @@ pub enum MQTTEvent {
     InvalidQosLevel,
     MissingMsgId,
     UnassignedMsgtype,
+    TooManyTransactions,
     MalformedTraffic,
 }
 
@@ -110,11 +115,12 @@ impl Drop for MQTTTransaction {
 pub struct MQTTState {
     tx_id: u64,
     pub protocol_version: u8,
-    transactions: Vec<MQTTTransaction>,
+    transactions: VecDeque<MQTTTransaction>,
     connected: bool,
     skip_request: usize,
     skip_response: usize,
     max_msg_len: usize,
+    tx_index_completed: usize,
 }
 
 impl MQTTState {
@@ -122,11 +128,12 @@ impl MQTTState {
         Self {
             tx_id: 0,
             protocol_version: 0,
-            transactions: Vec::new(),
+            transactions: VecDeque::new(),
             connected: false,
             skip_request: 0,
             skip_response: 0,
             max_msg_len: unsafe { MAX_MSG_LEN as usize },
+            tx_index_completed: 0,
         }
     }
 
@@ -143,6 +150,7 @@ impl MQTTState {
             }
         }
         if found {
+            self.tx_index_completed = 0;
             self.transactions.remove(index);
         }
     }
@@ -178,6 +186,18 @@ impl MQTTState {
         } else {
             tx.toserver = true;
         }
+        if self.transactions.len() > unsafe { MQTT_MAX_TX } {
+            let mut index = self.tx_index_completed;
+            for tx_old in self.transactions.iter_mut().skip(self.tx_index_completed) {
+                index = index + 1;
+                if !tx_old.complete {
+                    tx_old.complete = true;
+                    MQTTState::set_event(tx_old, MQTTEvent::TooManyTransactions);
+                    break;
+                }
+            }
+            self.tx_index_completed = index;
+        }
         return tx;
     }
 
@@ -195,18 +215,18 @@ impl MQTTState {
                 if self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::DoubleConnect);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     tx.pkt_id = Some(MQTT_CONNECT_PKT_ID);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::PUBLISH(ref publish) => {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 match msg.header.qos_level {
@@ -215,23 +235,23 @@ impl MQTTState {
                         // response
                         let mut tx = self.new_tx(msg, toclient);
                         tx.complete = true;
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     },
                     1..=2 => {
                         if let Some(pkt_id) = publish.message_id {
                             let mut tx = self.new_tx(msg, toclient);
                             tx.pkt_id = Some(pkt_id as u32);
-                            self.transactions.push(tx);
+                            self.transactions.push_back(tx);
                         } else {
                             let mut tx = self.new_tx(msg, toclient);
                             MQTTState::set_event(&mut tx, MQTTEvent::MissingMsgId);
-                            self.transactions.push(tx);
+                            self.transactions.push_back(tx);
                         }
                     },
                     _ => {
                         let mut tx = self.new_tx(msg, toclient);
                         MQTTState::set_event(&mut tx, MQTTEvent::InvalidQosLevel);
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     }
                 }
             },
@@ -239,7 +259,7 @@ impl MQTTState {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 let pkt_id = subscribe.message_id as u32;
@@ -249,17 +269,17 @@ impl MQTTState {
                         // response
                         let mut tx = self.new_tx(msg, toclient);
                         tx.complete = true;
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     },
                     1..=2 => {
                         let mut tx = self.new_tx(msg, toclient);
                         tx.pkt_id = Some(pkt_id);
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     },
                     _ => {
                         let mut tx = self.new_tx(msg, toclient);
                         MQTTState::set_event(&mut tx, MQTTEvent::InvalidQosLevel);
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     }
                 }
             },
@@ -267,7 +287,7 @@ impl MQTTState {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 let pkt_id = unsubscribe.message_id as u32;
@@ -277,17 +297,17 @@ impl MQTTState {
                         // response
                         let mut tx = self.new_tx(msg, toclient);
                         tx.complete = true;
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     },
                     1..=2 => {
                         let mut tx = self.new_tx(msg, toclient);
                         tx.pkt_id = Some(pkt_id);
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     },
                     _ => {
                         let mut tx = self.new_tx(msg, toclient);
                         MQTTState::set_event(&mut tx, MQTTEvent::InvalidQosLevel);
-                        self.transactions.push(tx);
+                        self.transactions.push_back(tx);
                     }
                 }
             },
@@ -300,7 +320,7 @@ impl MQTTState {
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::MissingConnect);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::PUBREC(ref v)
@@ -308,7 +328,7 @@ impl MQTTState {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 if let Some(tx) = self.get_tx_by_pkt_id(v.message_id as u32) {
@@ -316,7 +336,7 @@ impl MQTTState {
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::MissingPublish);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::PUBACK(ref v)
@@ -324,7 +344,7 @@ impl MQTTState {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 if let Some(tx) = self.get_tx_by_pkt_id(v.message_id as u32) {
@@ -334,14 +354,14 @@ impl MQTTState {
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::MissingPublish);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::SUBACK(ref suback) => {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 if let Some(tx) = self.get_tx_by_pkt_id(suback.message_id as u32) {
@@ -351,14 +371,14 @@ impl MQTTState {
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::MissingSubscribe);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::UNSUBACK(ref unsuback) => {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 if let Some(tx) = self.get_tx_by_pkt_id(unsuback.message_id as u32) {
@@ -368,43 +388,43 @@ impl MQTTState {
                 } else {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::MissingUnsubscribe);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                 }
             },
             MQTTOperation::UNASSIGNED => {
                 let mut tx = self.new_tx(msg, toclient);
                 tx.complete = true;
                 MQTTState::set_event(&mut tx, MQTTEvent::UnassignedMsgtype);
-                self.transactions.push(tx);
+                self.transactions.push_back(tx);
             },
             MQTTOperation::TRUNCATED(_) => {
                 let mut tx = self.new_tx(msg, toclient);
                 tx.complete = true;
-                self.transactions.push(tx);
+                self.transactions.push_back(tx);
             },
             MQTTOperation::AUTH(_)
             | MQTTOperation::DISCONNECT(_) => {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 let mut tx = self.new_tx(msg, toclient);
                 tx.complete = true;
-                self.transactions.push(tx);
+                self.transactions.push_back(tx);
             },
             MQTTOperation::PINGREQ
             | MQTTOperation::PINGRESP => {
                 if !self.connected {
                     let mut tx = self.new_tx(msg, toclient);
                     MQTTState::set_event(&mut tx, MQTTEvent::UnintroducedMessage);
-                    self.transactions.push(tx);
+                    self.transactions.push_back(tx);
                     return;
                 }
                 let mut tx = self.new_tx(msg, toclient);
                 tx.complete = true;
-                self.transactions.push(tx);
+                self.transactions.push_back(tx);
             }
         }
     }
@@ -563,7 +583,7 @@ impl MQTTState {
         }
         tx.complete = true;
         MQTTState::set_event(&mut tx, event);
-        self.transactions.push(tx);
+        self.transactions.push_back(tx);
     }
 }
 
@@ -738,6 +758,7 @@ pub extern "C" fn rs_mqtt_state_get_event_info_by_id(event_id: std::os::raw::c_i
             MQTTEvent::InvalidQosLevel     => { "invalid_qos_level\0" },
             MQTTEvent::MissingMsgId        => { "missing_msg_id\0" },
             MQTTEvent::UnassignedMsgtype   => { "unassigned_msg_type\0" },
+            MQTTEvent::TooManyTransactions => { "too_many_transactions\0" },
             MQTTEvent::MalformedTraffic    => { "malformed_traffic\0" },
         };
         unsafe{
@@ -855,6 +876,13 @@ pub unsafe extern "C" fn rs_mqtt_register_parser(cfg_max_msg_len: u32) {
         if AppLayerParserConfParserEnabled(ip_proto_str.as_ptr(), parser.name) != 0 {
             let _ = AppLayerRegisterParser(&parser, alproto);
         }
+        if let Some(val) = conf_get("app-layer.protocols.mqtt.max-tx") {
+            if let Ok(v) = val.parse::<usize>() {
+                MQTT_MAX_TX = v;
+            } else {
+                SCLogError!("Invalid value for mqtt.max-tx");
+            }
+        }
     } else {
         SCLogDebug!("Protocol detector and parser disabled for MQTT.");
     }
