@@ -653,15 +653,19 @@ impl NFSState {
     }
 
     pub fn process_write_record<'b>(&mut self, r: &RpcPacket<'b>, w: &Nfs3RequestWrite<'b>) -> u32 {
-        // for now assume that stable FILE_SYNC flags means a single chunk
-        let is_last = if w.stable == 2 { true } else { false };
-
         let mut fill_bytes = 0;
-        let pad = w.file_len % 4;
+        let pad = w.count % 4;
         if pad != 0 {
             fill_bytes = 4 - pad;
         }
 
+        // linux defines a max of 1mb. Allow several multiples.
+        if w.count == 0 || w.count > 16777216 {
+            return 0;
+        }
+
+        // for now assume that stable FILE_SYNC flags means a single chunk
+        let is_last = if w.stable == 2 { true } else { false };
         let file_handle = w.handle.value.to_vec();
         let file_name = if let Some(name) = self.namemap.get(w.handle.value) {
             SCLogDebug!("WRITE name {:?}", name);
@@ -711,8 +715,8 @@ impl NFSState {
         }
         if !self.is_udp {
             self.ts_chunk_xid = r.hdr.xid;
-            let file_data_len = w.file_data.len() as u32 - fill_bytes as u32;
-            self.ts_chunk_left = w.file_len as u32 - file_data_len as u32;
+            debug_validate_bug_on!(w.file_data.len() as u32 > w.count);
+            self.ts_chunk_left = w.count - w.file_data.len() as u32;
             self.ts_chunk_fh = file_handle;
             SCLogDebug!("REQUEST chunk_xid {:04X} chunk_left {}", self.ts_chunk_xid, self.ts_chunk_left);
         }
@@ -891,6 +895,17 @@ impl NFSState {
         let chunk_offset;
         let nfs_version;
 
+        let mut fill_bytes = 0;
+        let pad = reply.count % 4;
+        if pad != 0 {
+            fill_bytes = 4 - pad;
+        }
+
+        // linux defines a max of 1mb. Allow several multiples.
+        if reply.count == 0 || reply.count > 16777216 {
+            return 0;
+        }
+
         match xidmapr {
             Some(xidmap) => {
                 file_name = xidmap.file_name.to_vec();
@@ -912,11 +927,6 @@ impl NFSState {
         SCLogDebug!("chunk_offset {}", chunk_offset);
 
         let mut is_last = reply.eof;
-        let mut fill_bytes = 0;
-        let pad = reply.count % 4;
-        if pad != 0 {
-            fill_bytes = 4 - pad;
-        }
         SCLogDebug!("XID {} is_last {} fill_bytes {} reply.count {} reply.data_len {} reply.data.len() {}",
                 r.hdr.xid, is_last, fill_bytes, reply.count, reply.data_len, reply.data.len());
 
@@ -994,7 +1004,8 @@ impl NFSState {
 
         if !self.is_udp {
             self.tc_chunk_xid = r.hdr.xid;
-            self.tc_chunk_left = (reply.count as u32 + fill_bytes) - reply.data.len() as u32;
+            debug_validate_bug_on!(reply.data.len() as u32 > reply.count);
+            self.tc_chunk_left = reply.count - reply.data.len() as u32;
         }
 
         SCLogDebug!("REPLY {} to procedure {} blob size {} / {}: chunk_left {} chunk_xid {:04X}",
@@ -1047,6 +1058,62 @@ impl NFSState {
         return AppLayerResult::ok();
     }
 
+    /// Handle partial records
+    fn parse_tcp_partial_data_ts<'b>(&mut self, base_input: &'b[u8], cur_i: &'b[u8],
+            phdr: &RpcRequestPacketPartial, rec_size: usize) -> AppLayerResult {
+        // special case: avoid buffering file write blobs
+        // as these can be large.
+        if rec_size >= 512 && cur_i.len() >= 44 {
+            // large record, likely file xfer
+            SCLogDebug!("large record {}, likely file xfer", rec_size);
+
+            // quick peek, are we in WRITE mode?
+            if phdr.procedure == NFSPROC3_WRITE {
+                SCLogDebug!("CONFIRMED WRITE: large record {}, file chunk xfer", rec_size);
+
+                // lets try to parse the RPC record. Might fail with Incomplete.
+                match parse_rpc(cur_i, cur_i.len(), false) {
+                    Ok((_rem, ref hdr)) => {
+                        // we got here because rec_size > input, so we should never have
+                        // remaining data
+                        debug_validate_bug_on!(_rem.len() != 0);
+
+                        match parse_nfs3_request_write(hdr.prog_data, false) {
+                            Ok((_, ref w)) => {
+                                // deal with the partial nfs write data
+                                self.process_partial_write_request_record(hdr, w);
+                                return AppLayerResult::ok();
+                            }
+                            Err(nom::Err::Error(_e)) | Err(nom::Err::Failure(_e)) => {
+                                self.set_event(NFSEvent::MalformedData);
+                                SCLogDebug!("Parsing failed: {:?}", _e);
+                                return AppLayerResult::err();
+                            }
+                            Err(nom::Err::Incomplete(_)) => {
+                                // this is normal, fall through to incomplete handling
+                            }
+                        }
+                    }
+                    Err(nom::Err::Incomplete(_)) => {
+                        // size check was done for a minimal RPC record size,
+                        // so Incomplete is normal.
+                        SCLogDebug!("TS data incomplete");
+                    }
+                    Err(nom::Err::Error(_e)) | Err(nom::Err::Failure(_e)) => {
+                        self.set_event(NFSEvent::MalformedData);
+                        SCLogDebug!("Parsing failed: {:?}", _e);
+                        return AppLayerResult::err();
+                    }
+                }
+            }
+        }
+        // make sure we pass a value higher than current input
+        // but lower than the record size
+        let n1 = cmp::max(cur_i.len(), 1024);
+        let n2 = cmp::min(n1, rec_size);
+        return AppLayerResult::incomplete((base_input.len() - cur_i.len()) as u32, n2 as u32);
+    }
+
     /// Parsing function, handling TCP chunks fragmentation
     pub fn parse_tcp_data_ts<'b>(&mut self, i: &'b[u8]) -> AppLayerResult {
         let mut cur_i = i;
@@ -1097,81 +1164,31 @@ impl NFSState {
             match parse_rpc_request_partial(cur_i) {
                 Ok((_, ref rpc_phdr)) => {
                     let rec_size = (rpc_phdr.hdr.frag_len + 4) as usize;
-                    //SCLogDebug!("rec_size {}/{}", rec_size, cur_i.len());
-                    //SCLogDebug!("cur_i {:?}", cur_i);
 
+                    // Handle partial records
                     if rec_size > cur_i.len() {
-                        // special case: avoid buffering file write blobs
-                        // as these can be large.
-                        if rec_size >= 512 && cur_i.len() >= 44 {
-                            // large record, likely file xfer
-                            SCLogDebug!("large record {}, likely file xfer", rec_size);
-
-                            // quick peek, are in WRITE mode?
-                            if rpc_phdr.procedure == NFSPROC3_WRITE {
-                                SCLogDebug!("CONFIRMED WRITE: large record {}, file chunk xfer", rec_size);
-
-                                // lets try to parse the RPC record. Might fail with Incomplete.
-                                match parse_rpc(cur_i) {
-                                    Ok((remaining, ref rpc_record)) => {
-                                        match parse_nfs3_request_write(rpc_record.prog_data) {
-                                            Ok((_, ref nfs_request_write)) => {
-                                                // deal with the partial nfs write data
-                                                self.process_partial_write_request_record(rpc_record, nfs_request_write);
-                                                cur_i = remaining; // progress input past parsed record
-                                            },
-                                            _ => {
-                                                self.set_event(NFSEvent::MalformedData);
-                                            },
-                                        }
-                                    },
-                                    Err(nom::Err::Incomplete(_)) => {
-                                        // we just size checked for the minimal record size above,
-                                        // so if options are used (creds/verifier), we can still
-                                        // have Incomplete data. Fall through to the buffer code
-                                        // and try again on our next iteration.
-                                        SCLogDebug!("TS data incomplete");
-                                        // fall through to the incomplete below
-                                    },
-                                    Err(nom::Err::Error(_e)) |
-                                    Err(nom::Err::Failure(_e)) => {
-                                        self.set_event(NFSEvent::MalformedData);
-                                        SCLogDebug!("Parsing failed: {:?}", _e);
-                                        return AppLayerResult::err();
-                                    },
-                                }
-                            }
-                        }
-                        // make sure we pass a value higher than current input
-                        // but lower than the record size
-                        let n1 = cmp::max(cur_i.len(), 1024);
-                        let n2 = cmp::min(n1, rec_size);
-                        return AppLayerResult::incomplete((i.len() - cur_i.len()) as u32, n2 as u32);
+                        return self.parse_tcp_partial_data_ts(i, cur_i, rpc_phdr, rec_size);
                     }
 
                     // we have the full records size worth of data,
-                    // let's parse it
-                    match parse_rpc(&cur_i[..rec_size]) {
+                    // let's parse it. Errors lead to event, but are
+                    // not fatal as we already have enough info to
+                    // go to the next record.
+                    match parse_rpc(cur_i, cur_i.len(), true) {
                         Ok((_, ref rpc_record)) => {
-                            cur_i = &cur_i[rec_size..];
                             self.process_request_record(rpc_record);
-                        },
+                        }
                         Err(nom::Err::Incomplete(_)) => {
-                            cur_i = &cur_i[rec_size..]; // progress input past parsed record
-
-                            // we shouldn't get incomplete as we have the full data
-                            // so if we got incomplete anyway it's the data that is
-                            // bad.
                             self.set_event(NFSEvent::MalformedData);
-                        },
+                        }
                         Err(nom::Err::Error(_e)) |
                         Err(nom::Err::Failure(_e)) => {
                             self.set_event(NFSEvent::MalformedData);
                             SCLogDebug!("Parsing failed: {:?}", _e);
-                            return AppLayerResult::err();
-                        },
+                        }
                     }
-                },
+                    cur_i = &cur_i[rec_size..];
+                }
                 Err(nom::Err::Incomplete(needed)) => {
                     if let nom::Needed::Size(n) = needed {
                         SCLogDebug!("Not enough data for partial RPC header {:?}", needed);
@@ -1181,13 +1198,15 @@ impl NFSState {
                         return AppLayerResult::incomplete((i.len() - cur_i.len()) as u32, need as u32);
                     }
                     return AppLayerResult::err();
-                },
+                }
+                /* This error is fatal. If we failed to parse the RPC hdr we don't
+                 * have a length and we don't know where the next record starts. */
                 Err(nom::Err::Error(_e)) |
                 Err(nom::Err::Failure(_e)) => {
                     self.set_event(NFSEvent::MalformedData);
                     SCLogDebug!("Parsing failed: {:?}", _e);
                     return AppLayerResult::err();
-                },
+                }
             }
         };
 
@@ -1200,6 +1219,62 @@ impl NFSState {
         AppLayerResult::ok()
     }
 
+    /// Handle partial records
+    fn parse_tcp_partial_data_tc<'b>(&mut self, base_input: &'b[u8], cur_i: &'b[u8],
+            phdr: &RpcPacketHeader, rec_size: usize) -> AppLayerResult {
+        // special case: avoid buffering file read blobs
+        // as these can be large.
+        if rec_size >= 512 && cur_i.len() >= 128 {//36 {
+            // large record, likely file xfer
+            SCLogDebug!("large record {}, likely file xfer", rec_size);
+
+            // quick peek, are in READ mode?
+            if self.peek_reply_record(phdr) == NFSPROC3_READ {
+                SCLogDebug!("CONFIRMED large READ record {}, likely file chunk xfer", rec_size);
+
+                // we should have enough data to parse the RPC record
+                match parse_rpc_reply(cur_i, cur_i.len(), false) {
+                    Ok((_rem, ref hdr)) => {
+                        // we got here because rec_size > input, so we should never have
+                        // remaining data
+                        debug_validate_bug_on!(_rem.len() != 0);
+
+                        match parse_nfs3_reply_read(hdr.prog_data, false) {
+                            Ok((_, ref r)) => {
+                                // deal with the partial nfs read data
+                                self.process_partial_read_reply_record(hdr, r);
+                                return AppLayerResult::ok();
+                            }
+                            Err(nom::Err::Error(_e)) | Err(nom::Err::Failure(_e)) => {
+                                self.set_event(NFSEvent::MalformedData);
+                                SCLogDebug!("Parsing failed: {:?}", _e);
+                                return AppLayerResult::err();
+                            }
+                            Err(nom::Err::Incomplete(_)) => {
+                                // this is normal, fall through to incomplete handling
+                            }
+                        }
+                    }
+                    Err(nom::Err::Incomplete(_)) => {
+                        // size check was done for a minimal RPC record size,
+                        // so Incomplete is normal.
+                        SCLogDebug!("TC data incomplete");
+                    }
+                    Err(nom::Err::Error(_e)) | Err(nom::Err::Failure(_e)) => {
+                        self.set_event(NFSEvent::MalformedData);
+                        SCLogDebug!("Parsing failed: {:?}", _e);
+                        return AppLayerResult::err();
+                    }
+                }
+            }
+        }
+        // make sure we pass a value higher than current input
+        // but lower than the record size
+        let n1 = cmp::max(cur_i.len(), 1024);
+        let n2 = cmp::min(n1, rec_size);
+        return AppLayerResult::incomplete((base_input.len() - cur_i.len()) as u32, n2 as u32);
+    }
+
     /// Parsing function, handling TCP chunks fragmentation
     pub fn parse_tcp_data_tc<'b>(&mut self, i: &'b[u8]) -> AppLayerResult {
         let mut cur_i = i;
@@ -1248,82 +1323,32 @@ impl NFSState {
 
         while cur_i.len() > 0 {
             match parse_rpc_packet_header(cur_i) {
-                Ok((_, ref rpc_hdr)) => {
-                    let rec_size = (rpc_hdr.frag_len + 4) as usize;
+                Ok((_, ref rpc_phdr)) => {
+                    let rec_size = (rpc_phdr.frag_len + 4) as usize;
                     // see if we have all data available
                     if rec_size > cur_i.len() {
-                        // special case: avoid buffering file read blobs
-                        // as these can be large.
-                        if rec_size >= 512 && cur_i.len() >= 128 {//36 {
-                            // large record, likely file xfer
-                            SCLogDebug!("large record {}, likely file xfer", rec_size);
-
-                            // quick peek, are in READ mode?
-                            if self.peek_reply_record(&rpc_hdr) == NFSPROC3_READ {
-                                SCLogDebug!("CONFIRMED large READ record {}, likely file chunk xfer", rec_size);
-
-                                // we should have enough data to parse the RPC record
-                                match parse_rpc_reply(cur_i) {
-                                    Ok((remaining, ref rpc_record)) => {
-                                        match parse_nfs3_reply_read(rpc_record.prog_data) {
-                                            Ok((_, ref nfs_reply_read)) => {
-                                                // deal with the partial nfs read data
-                                                self.process_partial_read_reply_record(rpc_record, nfs_reply_read);
-                                                cur_i = remaining; // progress input past parsed record
-                                            },
-                                            Err(nom::Err::Incomplete(_)) => {
-                                            },
-                                            Err(nom::Err::Error(_e)) |
-                                            Err(nom::Err::Failure(_e)) => {
-                                                self.set_event(NFSEvent::MalformedData);
-                                                SCLogDebug!("Parsing failed: {:?}", _e);
-                                                return AppLayerResult::err();
-                                            }
-                                        }
-                                    },
-                                    Err(nom::Err::Incomplete(_)) => {
-                                        // size check was done for MINIMAL record size,
-                                        // so Incomplete is normal.
-                                        SCLogDebug!("TC data incomplete");
-                                    },
-                                    Err(nom::Err::Error(_e)) |
-                                    Err(nom::Err::Failure(_e)) => {
-                                        self.set_event(NFSEvent::MalformedData);
-                                        SCLogDebug!("Parsing failed: {:?}", _e);
-                                        return AppLayerResult::err();
-                                    }
-                                }
-                            }
-                        }
-                        // make sure we pass a value higher than current input
-                        // but lower than the record size
-                        let n1 = cmp::max(cur_i.len(), 1024);
-                        let n2 = cmp::min(n1, rec_size);
-                        return AppLayerResult::incomplete((i.len() - cur_i.len()) as u32, n2 as u32);
+                        return self.parse_tcp_partial_data_tc(i, cur_i, rpc_phdr, rec_size);
                     }
 
                     // we have the full data of the record, lets parse
-                    match parse_rpc_reply(&cur_i[..rec_size]) {
+                    match parse_rpc_reply(cur_i, cur_i.len(), true) {
                         Ok((_, ref rpc_record)) => {
-                            cur_i = &cur_i[rec_size..]; // progress input past parsed record
                             self.process_reply_record(rpc_record);
-                        },
+                        }
                         Err(nom::Err::Incomplete(_)) => {
-                            cur_i = &cur_i[rec_size..]; // progress input past parsed record
-
                             // we shouldn't get incomplete as we have the full data
                             // so if we got incomplete anyway it's the data that is
                             // bad.
                             self.set_event(NFSEvent::MalformedData);
-                        },
+                        }
                         Err(nom::Err::Error(_e)) |
                         Err(nom::Err::Failure(_e)) => {
                             self.set_event(NFSEvent::MalformedData);
                             SCLogDebug!("Parsing failed: {:?}", _e);
-                            return AppLayerResult::err();
                         }
                     }
-                },
+                    cur_i = &cur_i[rec_size..]; // progress input past parsed record
+                }
                 Err(nom::Err::Incomplete(needed)) => {
                     if let nom::Needed::Size(n) = needed {
                         SCLogDebug!("Not enough data for partial RPC header {:?}", needed);
@@ -1333,13 +1358,15 @@ impl NFSState {
                         return AppLayerResult::incomplete((i.len() - cur_i.len()) as u32, need as u32);
                     }
                     return AppLayerResult::err();
-                },
+                }
+                /* This error is fatal. If we failed to parse the RPC hdr we don't
+                 * have a length and we don't know where the next record starts. */
                 Err(nom::Err::Error(_e)) |
                 Err(nom::Err::Failure(_e)) => {
                     self.set_event(NFSEvent::MalformedData);
                     SCLogDebug!("Parsing failed: {:?}", _e);
                     return AppLayerResult::err();
-                },
+                }
             }
         };
         self.post_gap_housekeeping(STREAM_TOCLIENT);
@@ -1752,7 +1779,7 @@ fn nfs_probe_dir(i: &[u8], rdir: *mut u8) -> i8 {
 
 pub fn nfs_probe(i: &[u8], direction: u8) -> i8 {
     if direction == STREAM_TOCLIENT {
-        match parse_rpc_reply(i) {
+        match parse_rpc_reply(i, i.len(), false) {
             Ok((_, ref rpc)) => {
                 if rpc.hdr.frag_len >= 24 && rpc.hdr.frag_len <= 35000 && rpc.hdr.msgtype == 1 && rpc.reply_state == 0 && rpc.accept_state == 0 {
                     SCLogDebug!("TC PROBE LEN {} XID {} TYPE {}", rpc.hdr.frag_len, rpc.hdr.xid, rpc.hdr.msgtype);
@@ -1784,7 +1811,7 @@ pub fn nfs_probe(i: &[u8], direction: u8) -> i8 {
             },
         }
     } else {
-        match parse_rpc(i) {
+        match parse_rpc(i, i.len(), false) {
             Ok((_, ref rpc)) => {
                 if rpc.hdr.frag_len >= 40 && rpc.hdr.msgtype == 0 &&
                    rpc.rpcver == 2 && (rpc.progver == 3 || rpc.progver == 4) &&
