@@ -51,12 +51,12 @@ use crate::smb::events::*;
 use crate::smb::files::*;
 use crate::smb::smb2_ioctl::*;
 
-pub static mut SMB_CFG_MAX_READ_SIZE: u32 = 0;
-pub static mut SMB_CFG_MAX_READ_QUEUE_SIZE: u32 = 0;
-pub static mut SMB_CFG_MAX_READ_QUEUE_CNT: u32 = 0;
-pub static mut SMB_CFG_MAX_WRITE_SIZE: u32 = 0;
-pub static mut SMB_CFG_MAX_WRITE_QUEUE_SIZE: u32 = 0;
-pub static mut SMB_CFG_MAX_WRITE_QUEUE_CNT: u32 = 0;
+pub static mut SMB_CFG_MAX_READ_SIZE: u32 = 16777216;
+pub static mut SMB_CFG_MAX_READ_QUEUE_SIZE: u32 = 67108864;
+pub static mut SMB_CFG_MAX_READ_QUEUE_CNT: u32 = 64;
+pub static mut SMB_CFG_MAX_WRITE_SIZE: u32 = 16777216;
+pub static mut SMB_CFG_MAX_WRITE_QUEUE_SIZE: u32 = 67108864;
+pub static mut SMB_CFG_MAX_WRITE_QUEUE_CNT: u32 = 64;
 
 pub const MIN_REC_SIZE: u16 = 32 + 4; // SMB hdr + nbss hdr
 
@@ -2260,4 +2260,9 @@ pub unsafe extern "C" fn rs_smb_set_conf_val(max_read_size: u32, max_write_size:
     SMB_CFG_MAX_WRITE_QUEUE_CNT = max_write_queue_cnt;
     SMB_CFG_MAX_READ_QUEUE_SIZE = max_read_queue_size;
     SMB_CFG_MAX_READ_QUEUE_CNT = max_read_queue_cnt;
+
+    SCLogConfig!("read: max record size: {}, max queued chunks {}, max queued size {}",
+            SMB_CFG_MAX_READ_SIZE, SMB_CFG_MAX_READ_QUEUE_CNT, SMB_CFG_MAX_READ_QUEUE_SIZE);
+    SCLogConfig!("write: max record size: {}, max queued chunks {}, max queued size {}",
+            SMB_CFG_MAX_WRITE_SIZE, SMB_CFG_MAX_WRITE_QUEUE_CNT, SMB_CFG_MAX_WRITE_QUEUE_SIZE);
 }
