@@ -58,7 +58,6 @@
 #include "app-layer-htp.h"
 #include "app-layer-dcerpc-common.h"
 #include "app-layer-dcerpc.h"
-#include "app-layer-dns-common.h"
 
 #include "util-unittest.h"
 #include "util-unittest-helper.h"
@@ -663,8 +662,7 @@ static int DeStateSigTest03(void)
     SigMatchSignatures(&th_v, de_ctx, det_ctx, p);
     FAIL_IF(!(PacketAlertCheck(p, 1)));
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
 
     File *file = files->head;
@@ -741,8 +739,7 @@ static int DeStateSigTest04(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -818,8 +815,7 @@ static int DeStateSigTest05(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -896,8 +892,7 @@ static int DeStateSigTest06(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -979,8 +974,7 @@ static int DeStateSigTest07(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -1077,8 +1071,7 @@ static int DeStateSigTest08(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -1102,8 +1095,7 @@ static int DeStateSigTest08(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     file = files->head;
     FAIL_IF_NULL(file);
@@ -1202,8 +1194,7 @@ static int DeStateSigTest09(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -1227,8 +1218,7 @@ static int DeStateSigTest09(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     file = files->head;
     FAIL_IF_NULL(file);
@@ -1325,8 +1315,7 @@ static int DeStateSigTest10(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    FileContainer *files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    FileContainer *files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     File *file = files->head;
     FAIL_IF_NULL(file);
@@ -1350,8 +1339,7 @@ static int DeStateSigTest10(void)
     FAIL_IF_NULL(http_state);
     FAIL_IF_NULL(http_state->files_ts);
 
-    files = AppLayerParserGetFiles(p->flow->proto, p->flow->alproto,
-                                                  p->flow->alstate, STREAM_TOSERVER);
+    files = AppLayerParserGetFiles(p->flow, STREAM_TOSERVER);
     FAIL_IF_NULL(files);
     file = files->head;
     FAIL_IF_NULL(file);
