@@ -1864,7 +1864,7 @@ void TmThreadContinue(ThreadVars *tv)
 /**
  * \brief Unpauses all threads present in tv_root
  */
-void TmThreadContinueThreads()
+void TmThreadContinueThreads(void)
 {
     SCMutexLock(&tv_root_lock);
     for (int i = 0; i < TVT_MAX; i++) {
@@ -1892,7 +1892,7 @@ void TmThreadPause(ThreadVars *tv)
 /**
  * \brief Pauses all threads present in tv_root
  */
-void TmThreadPauseThreads()
+void TmThreadPauseThreads(void)
 {
     TmThreadsListThreads();
 
@@ -2291,7 +2291,7 @@ void TmThreadsGetMinimalTimestamp(struct timeval *ts)
     SCLogDebug("ts->tv_sec %"PRIuMAX, (uintmax_t)ts->tv_sec);
 }
 
-uint16_t TmThreadsGetWorkerThreadMax()
+uint16_t TmThreadsGetWorkerThreadMax(void)
 {
     uint16_t ncpus = UtilCpuGetNumProcessorsOnline();
     int thread_max = TmThreadGetNbThreads(WORKER_CPU_SET);
