@@ -367,6 +367,9 @@ typedef enum {
     SC_ERR_PLUGIN,
     SC_ERR_LOG_OUTPUT,
     SC_ERR_RULE_INVALID_UTF8,
+    SC_WARN_CHOWN,
+    SC_ERR_HASH_ADD,
+    SC_ERR_SIGNAL,
 
     SC_ERR_MAX
 } SCError;
